import 'package:flutter/material.dart';

import 'ocr_camera_widget.dart';

class MyMask extends CustomPainter {
  final Color outerBackgroundColor;
  final MaskType pathBorderType;

  MyMask({
    required this.outerBackgroundColor,
    this.pathBorderType = MaskType.passport,
  });

  @override
  void paint(Canvas canvas, Size size) {
    final outerRect = RRect.fromLTRBR(
      0,
      0,
      size.width,
      size.height,
      const Radius.circular(0.00001),
    );

    late Path innerRectPath;
    if (pathBorderType == MaskType.idCard) {
      innerRectPath = Path()
        ..addRRect(RRect.fromLTRBR(
          size.width * 0.05,
          (size.height / 2) - ((size.width * 0.9) / 3 * 2) / 2,
          size.width * 0.95,
          (size.height / 2) + ((size.width * 0.9) / 3 * 2) / 2,
          const Radius.circular(16),
        ));
    } else if (pathBorderType == MaskType.passport) {
      innerRectPath = Path()
        ..addRRect(
          RRect.fromLTRBR(
            size.width * 0.05,
            (size.height / 2) - ((size.width * 0.9) / 3 * 4) / 2,
            size.width * 0.95,
            (size.height / 2) + ((size.width * 0.9) / 3 * 4) / 2,
            const Radius.circular(16),
          ),
        );
    } else {
      innerRectPath = Path()
        ..addOval(Rect.fromLTWH(size.width / 6, size.height / 4,
            size.width / 1.5, size.height / 2));
    }

    // draw outer rectangle with a hole in center
    canvas.drawPath(
      Path.combine(
        PathOperation.difference,
        Path()..addRRect(outerRect),
        innerRectPath..close(),
      ),
      Paint()..color = outerBackgroundColor,
    );

    // draw inner rectangle above hole in the center
    canvas.drawPath(
        innerRectPath,
        Paint()
          ..color = Colors.white
          ..strokeWidth = 2
          ..style = PaintingStyle.stroke);
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    return false;
  }
}
